@@ -2,7 +2,7 @@ import numpy as np
 import pyneb as pn
 
 ELEM_LIST = ['Ag', 'Al', 'Ar', 'Au', 'B', 'Ba', 'C', 'Ca', 'Cl', 'Co', 'Cr', 'Cu', 'F', 'Fe', 'H', 'He', 'K',
-             'Kr', 'Mg', 'N', 'Na', 'Ne', 'Ni', 'O', 'P', 'S', 'Si', 'Xe', 'Zn', 'Se', 'Br', 'Rb']
+             'Kr', 'Mg', 'N', 'Na', 'Ne', 'Ni', 'O', 'P', 'S', 'Si', 'Xe', 'Zn', 'Se', 'Br', 'Rb', '3He']
 SPEC_LIST = ['1', '2', '3', '4', '5', '6', '7']
 
 def _print_LINE_LABEL_LIST(*args, **kwargs):
@@ -12,7 +12,7 @@ def _print_LINE_LABEL_LIST(*args, **kwargs):
     ##
     # @todo we have to check what are the differences in LINE_LABEL_LIST when changing the fits files
     all_atoms = pn.getAtomDict(*args, **kwargs)
-    print "LINE_LABEL_LIST = {}"
+    print("LINE_LABEL_LIST = {}")
     for atom in np.sort(all_atoms.keys()):
         wave = all_atoms[atom].lineList
         opt = (wave < 10000.)
@@ -20,7 +20,7 @@ def _print_LINE_LABEL_LIST(*args, **kwargs):
         lines_opt = ["'%.0fA'" % line for line in np.sort(wave[opt])]
         lines_ir = ["'%.1fm'" % line for line in np.sort(wave[ir]) / 1.e4]
         lines = lines_opt + lines_ir
-        print "LINE_LABEL_LIST['" + atom + "'] = [" + ', '.join(lines) + "]"
+        print("LINE_LABEL_LIST['" + atom + "'] = [" + ', '.join(lines) + "]")
 
 def _check_line_label_list(maxErrorA = 5.e-3, maxErrorm = 5.e-2):
     for ion in LINE_LABEL_LIST:
@@ -40,6 +40,7 @@ LINE_LABEL_LIST['He1r'] = ['5876A', '2945A', '3188A', '3614A', '3889A', '3965A',
                           '18685A', '18697A', '19089A', '19543A', '20425A', '20581A', '20602A', '21120A',
                           '21132A', '21608A', '21617A']
 LINE_LABEL_LIST['He2r'] = ['1640A', '1215A', '1084A', '4686A', '3203A','6560A', '5411A','4859A']
+LINE_LABEL_LIST['3He2'] = ['3.50c']
 LINE_LABEL_LIST['Al2'] = ['2674A', '2670A', '2661A', '1671A', '4451A', '4463A', '4488A', '164.2m', '54.1m', '80.7m']
 LINE_LABEL_LIST['Ar2'] = ['7.0m']
 LINE_LABEL_LIST['Ar3'] = ['7136A', '7751A', '8036A', '3005A', '3109A', '3154A', '5192A', '9.0m', '6.37m', '21.8m']
@@ -98,7 +99,7 @@ LINE_LABEL_LIST['Ne6'] = ['997A', '1010A', '993A', '1006A', '986A', '999A', '559
                           '1929A', '7.65m', '22.7m', '9.2m', '15.5m', '334.4m']
 LINE_LABEL_LIST['Ni3'] = ['7890A', '8500A', '6000A', '6401A', '6534A', '6682A', '6797A', '7125A', '6946A']
 LINE_LABEL_LIST['O1'] = ['6300A', '6364A', '6392A', '2959A', '2973A', '2979A', '5577A', '63.2m', '44.1m', '145.5m']
-LINE_LABEL_LIST['O2'] = ['3729A', '3726A', '2470A', '7319A', '7330A', '2470A', '7318A', '7329A', '834A', '1075A', 
+LINE_LABEL_LIST['O2'] = ['3729A', '3726A', '2470A', '7319A','7320A', '7330A', '7331A', '2470A', '834A', '1075A', 
                          '1260A', '833A', '1073A', '1258A', '833A', '1072A', '1256A', '499.3m', '5023.7m', '61.3m', 
                          '40.7m', '121.3m']
 LINE_LABEL_LIST['O3'] = ['4931A', '4959A', '5007A', '2315A', '2321A', '2331A', '4363A', '1658A', '1661A', '1666A', 
