@@ -2,9 +2,9 @@ import os
 import pyneb as pn
 import numpy as np
 import re
-from misc import execution_path, parseAtom, roman_to_int, multi_split, int_to_roman, strExtract
-from init import ELEM_LIST, SPEC_LIST
-from physics import _predefinedDataFileDict
+from .misc import execution_path, parseAtom, roman_to_int, multi_split, int_to_roman, strExtract, bs
+from .init import ELEM_LIST, SPEC_LIST
+from .physics import _predefinedDataFileDict
 
 def atom2chianti(atom):
     elem = parseAtom(atom)[0]
@@ -269,8 +269,8 @@ class _ManageAtomicData(object):
                                 pass
         coll_atom_list = list(set(atom_dict['atom']) & set(atom_dict['coll']))
         rec_atom_list = list(set(atom_dict['rec']))
-        print 'Data for the following collisional atoms exist:', coll_atom_list
-        print 'Data for the following recombination atoms exist:', rec_atom_list
+        print('Data for the following collisional atoms exist:', coll_atom_list)
+        print('Data for the following recombination atoms exist:', rec_atom_list)
         return [coll_atom_list, rec_atom_list] 
         
     
@@ -486,7 +486,12 @@ class _ManageAtomicData(object):
                     for line in master.readlines():
                         atom = line.split()[0]
                         elem = atom.split('_')[0]
-                        coll_file = '{0}/{1}/{2}/{2}.splups'.format(self.Chianti_path, elem, atom)
+                        if pn.config.Chianti_version_main == '7':
+                            coll_file = '{0}/{1}/{2}/{2}.splups'.format(self.Chianti_path, elem, atom)
+                        elif pn.config.Chianti_version_main == '8':
+                            coll_file = '{0}/{1}/{2}/{2}.scups'.format(self.Chianti_path, elem, atom)
+                        else:
+                            pn.config.error('Unknown version of Chianti {}'.format(pn.config.Chianti_version))
                         atom_file = '{0}/{1}/{2}/{2}.wgfa'.format(self.Chianti_path, elem, atom)
                         if os.path.exists(coll_file): 
                             self.ChiantiIONS['coll'].append(atom)
@@ -505,27 +510,24 @@ class _ManageAtomicData(object):
  
         """
         if (yr == 96):
-            print "********************************************"
-            print ""
-            print "We have used a near limitless data source,"
-            print "It is the Opacity Project, of course."
-            print "Its results are certainly fine"
-            print "For most any LS-coupled line."        
-            print ""
-            print "            (Wiese, Fuhr & Deters 1996)"
-            print ""
-            print "********************************************"
+            print("""********************************************
+            
+We have used a near limitless data source,
+It is the Opacity Project, of course.
+Its results are certainly fine
+For most any LS-coupled line.
+
+
+(Wiese, Fuhr & Deters 1996)""")            
         elif (yr == 66):
-            print "********************************************"
-            print ""
-            print "If there is no other data source"
-            print "Use the Coulomb approximation, of course."    
-            print "The results should be certainly fine"
-            print "For any moderately or highly excited line."
-            print ""
-            print "            (Wiese, Smith & Glennon 1966)" 
-            print ""
-            print "********************************************"
+            print("""********************************************
+
+If there is no other data source            
+Use the Coulomb approximation, of course.
+The results should be certainly fine
+For any moderately or highly excited line.
+
+(Wiese, Smith & Glennon 1966)""")
         else:
             rnd = np.random.rand()
             if (rnd < 0.5):
@@ -541,7 +543,7 @@ def extract_flt(str_):
     extract_flt('123.00?') -> 123.00
     """
     res = ''
-    for l in str_:
+    for l in bs(str_):
         if l.isdigit() or l == '.':
             res += l
         else:
@@ -552,13 +554,13 @@ def extract_flt(str_):
         return float(res)
 
 
-def readNIST(NISTfile):
+def readNIST(NISTfile,NLevels=None):
     """
     The NIST levels file must be obtained from this page:
         http://physics.nist.gov/PhysRefData/ASD/levels_form.html
     with the following options:
         Level Units: cm-1
-        Format output: ASCII
+        Format output: ASCIIda
         Display output: in its entirely
         Energy ordered
         Level Information: Principal configuration, Principal term, Level, J
@@ -567,7 +569,7 @@ def readNIST(NISTfile):
     data = np.genfromtxt(NISTfile, comments = '-', 
                     delimiter = '|', names = 'conf, term, J, energy, ref', 
                     dtype=('a23', 'a9', 'a4', 'float', 'a10'), autostrip=True,
-                    converters = {'energy':extract_flt})
+                    converters = {'energy':extract_flt, 'J':bs, 'conf':bs, 'term': bs, 'ref':bs})
     data = data[data['J'] != '']
     previous_ref = ''
     previous_conf = ''
@@ -596,10 +598,12 @@ def readNIST(NISTfile):
            
     data = data[data['energy'].argsort()]
     data = data.astype([('conf', 'a23'), ('term', 'a9'), ('J', 'float'), ('energy', 'float'), ('ref', 'a10')])
+    if NLevels is not None:
+        data = data[0:NLevels]
     return data
 
 
-def getLevelsNIST(atom, Nmax = None):
+def getLevelsNIST(atom, NLevels = None):
     """
     Return a numpy.array containing the NIST data related to the levels for the given atom
     The keys of the recarry are: conf, term, J, energy, ref
@@ -615,11 +619,8 @@ def getLevelsNIST(atom, Nmax = None):
     level_file = '{0}_levels.dat'.format(atom_str)
     file_ = execution_path('../atomic_data/levels/{0}'.format(level_file))
     if os.path.isfile(file_):
-        data = readNIST(file_)
+        data = readNIST(file_, NLevels=NLevels)
         pn.log_.message('Reading energies and stat weights from {0}'.format(level_file), calling='getLevelsNIST')
-        if Nmax is not None:
-            if Nmax < len(data):
-                data = data[0:Nmax]
         return data
     else:
         return None
