@@ -3,13 +3,16 @@ from scipy import interpolate
 import os
 import re
 import pyneb as pn
-import _chianti_tools
-import _chianti_constants as const
-from physics import sym2name, vactoair
-from manage_atomic_data import getLevelsNIST, atom2chianti
-from misc import parseAtom
+if pn.config.Chianti_version_main == '8':
+    from . import _chianti_tools_8 as _chianti_tools
+elif pn.config.Chianti_version_main == '7':
+    from . import _chianti_tools
+from . import _chianti_constants as const
+from .physics import sym2name, vactoair
+from .manage_atomic_data import getLevelsNIST, atom2chianti
+from .misc import parseAtom
 
-def Chianti_getA(ion_chianti):
+def Chianti_getA(ion_chianti, NLevels=None):
     """
     Return As from Chianti database.
     Usage:
@@ -20,14 +23,17 @@ def Chianti_getA(ion_chianti):
     As = np.zeros((NLevels, NLevels))
     for i, j, a in zip(wgfa['lvl2'], wgfa['lvl1'], wgfa['avalue']):
         As[i-1, j-1] = a
+    if NLevels is not None:
+        As = As[0:NLevels, 0:NLevels]
     return As
 
-def Chianti_getE(ion_chianti):
+def Chianti_getE(ion_chianti, NLevels=None):
     """
     Return energies from the Chianti database
     Usage:
         E_O3 = Chianti_getE('o_3')
     """
+    
     Es = _chianti_tools.elvlcRead(ion_chianti)
     if not 'j' in Es:
         return None
@@ -36,11 +42,13 @@ def Chianti_getE(ion_chianti):
              ('conf', '<i8'), ('lvl', '<i8'), ('spin', '<i8'), ('eryd', '<f8'), ('mult', '<i8')]
     arr = np.recarray((len(Es['j']),), dtype=dtype)
     for k in Es.keys():
-        if k not in ('status', 'ref'):
+        if k not in ('status', 'ref', 'label', 'filename'):
             arr[k] = Es[k]
+    if NLevels is not None:
+        arr = arr[0:NLevels]
     return arr
 
-def get_levs_order(atom, nmax=None):
+def get_levs_order(atom, NLevels=None):
     """
     Returns a dictionary giving the correspondence of indices between NIST and Chianti energy level tables.
     
@@ -64,7 +72,7 @@ def get_levs_order(atom, nmax=None):
     for i_N, E in enumerate(E_NIST):
         if i_N >= len(E_chianti):
             break
-        if nmax is not None and i_N > nmax:
+        if NLevels is not None and i_N > NLevels:
             break
         
         term = remove_stars(E['term'])
@@ -100,11 +108,15 @@ def get_levs_order(atom, nmax=None):
             pretty = '{0} {1}{2}'.format(conf, term, E['J'])
             i_Ch = np.where(E_chianti['pretty'] == pretty)[0]
             if len(i_Ch) == 1:
-                Chianti2NIST[i_N] = i_Ch[0]
-                        
+                if NLevels is not None and i_Ch[0] <= NLevels:
+                    Chianti2NIST[i_N] = i_Ch[0]
+    if len(Chianti2NIST) == 0:
+        Chianti2NIST = None
+        
+        ### Il faut que ni i_N ni i_Ch depasse NLvels. Et il faut que NLevels soit diminue dansla cas contraire.
     return Chianti2NIST
         
-def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevelsMax=None):
+def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevels=None):
     """
     Return the values of Upsilon at a given temperature (may be a table)
     Usage:
@@ -116,13 +128,17 @@ def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevel
     """
     temp=np.asarray(tem)
     if Splups is None:
-        Splups = _chianti_tools.splupsRead(ion_chianti)
-    if NLevelsMax is None:
+        if pn.config.Chianti_version_main == '8':
+            Splups = _chianti_tools.scupsRead(ion_chianti)
+            print(Splups.keys())
+        elif pn.config.Chianti_version_main == '7':
+            Splups = _chianti_tools.splupsRead(ion_chianti)
+    if NLevels is None:
         nsplups = len(Splups["lvl1"])
         nlevels = np.max(Splups["lvl2"])
     else:
-        nsplups = np.min((len(Splups["lvl1"]), NLevelsMax))
-        nlevels = np.min((np.max(Splups["lvl2"]), NLevelsMax))
+        nsplups = np.min((len(Splups["lvl1"]), NLevels))
+        nlevels = np.min((np.max(Splups["lvl2"]), NLevels))
     ntemp=temp.size
     if (lev1 is None) and (lev2 is None):
         Omega = np.zeros((nlevels, nlevels, ntemp))
@@ -148,46 +164,47 @@ def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevel
             else:
                 ttype=Splups["ttype"][isplups]
                 cups=Splups["cups"][isplups]
-                nspl=Splups["nspl"][isplups]
-                dx=1./(float(nspl)-1.)
-                splups=Splups["splups"][isplups]
+                if pn.config.Chianti_version_main == '8':
+                    nspl=Splups["ntemp"][isplups]
+                    dx=1./(float(nspl)-1.)
+                    xs = Splups['btemp'][isplups]
+                    splups=Splups["bscups"][isplups]
+                elif pn.config.Chianti_version_main == '7':
+                    nspl=Splups["nspl"][isplups]
+                    dx=1./(float(nspl)-1.)
+                    xs=dx*np.arange(nspl)
+                    splups=Splups["splups"][isplups]
                 de=Splups['de'][isplups]
                 kte = const.boltzmann*temp/(de*const.ryd2erg)
                 der=0
                 if ttype == 1:
                     st=1.-np.log(cups)/np.log(kte+cups)
-                    xs=dx*np.arange(nspl)
                     y2=interpolate.splrep(xs,splups,s=0)
                     sups=interpolate.splev(st,y2,der=der)
                     ups=sups*np.log(kte+np.exp(1.))
                 elif ttype == 2:
                     st=kte/(kte+cups)
-                    xs=dx*np.arange(nspl)
                     y2=interpolate.splrep(xs,splups,s=0)
                     sups=interpolate.splev(st,y2,der=der)
                     ups=sups
                 elif ttype == 3:
                     st=kte/(kte+cups)
-                    xs=dx*np.arange(nspl)
                     y2=interpolate.splrep(xs,splups,s=0)
                     sups=interpolate.splev(st,y2,der=der)
                     ups=sups/(kte+1.)
                 elif ttype == 4:
                     st=1.-np.log(cups)/np.log(kte+cups)
-                    xs=dx*np.arange(nspl)
                     y2=interpolate.splrep(xs,splups,s=0)
                     sups=interpolate.splev(st,y2,der=der)
                     ups=sups*np.log(kte+cups)
                 elif ttype == 5:
                     # dielectronic rates
                     st=kte/(kte+cups)
-                    xs=dx*np.arange(nspl)
                     y2=interpolate.splrep(xs,splups,s=0)
                     sups=interpolate.splev(st,y2,der=der)
                     ups=sups/(kte+0.)
                 elif ttype == 6:
                     st=kte/(kte+cups)
-                    xs=dx*np.arange(nspl)
                     y2=interpolate.splrep(xs,splups,s=0)
                     sups=interpolate.splev(st,y2,der=der)
                     ups=10.**sups
@@ -203,7 +220,7 @@ def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevel
 
 class _AtomChianti(object):
     
-    def __init__(self, elem=None, spec=None, atom=None):
+    def __init__(self, elem=None, spec=None, atom=None, NLevels=None):
         """
         Object dealing with As values from the Chianti database.
         The directory where to find the data must be given through the environment variable XUVTOP.
@@ -221,6 +238,8 @@ class _AtomChianti(object):
         self.name = sym2name[self.elem]
         self.ion_chianti =  atom2chianti(self.atom)
         self.calling = 'Atom {}'.format(self.atom)
+        self.Chianti2NIST = None
+        self.NLevels = NLevels
         self._loadChianti()
         self.initWaves()
         
@@ -236,8 +255,9 @@ class _AtomChianti(object):
         self.Chianti_version = self.atomPath.split('/')[-4]
         self.comments = {}
         
-        Chianti_A = Chianti_getA(self.ion_chianti)
-        self.Chianti2NIST = get_levs_order(self.atom)
+        Chianti_A = Chianti_getA(self.ion_chianti, NLevels=self.NLevels)
+        if self.Chianti2NIST is None:
+            self.Chianti2NIST = get_levs_order(self.atom)
         if self.Chianti2NIST is not None:
             Chianti_A_tmp = Chianti_A.copy()
             for i_chianti in self.Chianti2NIST:
@@ -245,10 +265,11 @@ class _AtomChianti(object):
                     Chianti_A[i_chianti,:] = Chianti_A_tmp[self.Chianti2NIST[i_chianti],:]
                     Chianti_A[:,i_chianti] = Chianti_A_tmp[:,self.Chianti2NIST[i_chianti]]
         self.log_.message('Reading atom data from Chianti {}'.format(self.atomFile), calling = self.calling)
-        self.Chianti_E = Chianti_getE(self.ion_chianti)
-        NLevels = len(self.Chianti_E)
-        self.NIST = getLevelsNIST(self.atom, NLevels)
-        NLevels = np.min((len(self.NIST), NLevels))
+        self.Chianti_E = Chianti_getE(self.ion_chianti, NLevels=self.NLevels)
+        if self.NLevels is None:
+            self.NLevels = len(self.Chianti_E)
+        self.NIST = getLevelsNIST(self.atom, self.NLevels)
+        self.NLevels = np.min((len(self.NIST), self.NLevels))
         need_NIST = True
         
         if self.NIST is not None:
@@ -264,8 +285,7 @@ class _AtomChianti(object):
         self._Energy = energy
         self._StatWeight = stat_weight
         self._A = Chianti_A
-        self.atomNLevels = NLevels
-        self.NLevels = self.atomNLevels
+        self.atomNLevels = self.NLevels
             
     def initWaves(self):
         """
@@ -392,7 +412,7 @@ class _AtomChianti(object):
                
 class _CollChianti(object):
     
-    def __init__(self, elem=None, spec=None, atom=None, NLevelsMax=None, TemArray=np.logspace(2, 5, 20)):
+    def __init__(self, elem=None, spec=None, atom=None, NLevels=None, TemArray=np.logspace(2, 5, 20)):
         """
         Object dealing with Upsilon values from the Chianti database.
         The directory where to find the data must be given through the environment variable XUVTOP.
@@ -412,14 +432,16 @@ class _CollChianti(object):
         self.name = sym2name[self.elem]
         self.ion_chianti =  atom2chianti(self.atom)
         self.calling = 'Atom ' + self.atom
-        self.NLevelsMax = NLevelsMax
+        self.NLevels = NLevels
         self.tem_units = 'K'
         self._TemArray = TemArray
         self._loadChianti()
         
     def _loadChianti(self):
-        self.fullFileName = _chianti_tools.ion2filename(self.ion_chianti) + '.splups'
-        
+        if pn.config.Chianti_version_main == '8':
+            self.fullFileName = _chianti_tools.ion2filename(self.ion_chianti) + '.scups'
+        elif pn.config.Chianti_version_main == '7':
+            self.fullFileName = _chianti_tools.ion2filename(self.ion_chianti) + '.splups'
         self.collFile = self.fullFileName.split('/')[-1]
         self.collPath = self.fullFileName[:-len(self.collFile)]
         
@@ -428,12 +450,14 @@ class _CollChianti(object):
         
         self.Chianti_version = self.collPath.split('/')[-4]
         self.comments = {}
-        self.Splups = _chianti_tools.splupsRead(self.ion_chianti)
-        
+        if pn.config.Chianti_version_main == '8':
+            self.Splups = _chianti_tools.scupsRead(self.ion_chianti)
+        elif pn.config.Chianti_version_main == '7':
+            self.Splups = _chianti_tools.splupsRead(self.ion_chianti)
         self._CollArray = Chianti_getOmega(self.ion_chianti, tem=self._TemArray, 
-                                   Splups=self.Splups, NLevelsMax=self.NLevelsMax)
+                                   Splups=self.Splups, NLevels=self.NLevels)
         
-        self.Chianti2NIST = get_levs_order(self.atom)
+        self.Chianti2NIST = get_levs_order(self.atom, NLevels=self.NLevels)
         if self.Chianti2NIST is not None:
             _CollArray_tmp = self._CollArray.copy()
             for i_chianti in self.Chianti2NIST:
@@ -442,8 +466,7 @@ class _CollChianti(object):
                     self._CollArray[:,i_chianti,:] = _CollArray_tmp[:,self.Chianti2NIST[i_chianti],:]
         
         self.log_.message('Reading coll data from Chianti {}'.format(self.collFile), calling = self.calling)
-        self.collNLevels = self._CollArray.shape[0]
-        self.NLevels = self.collNLevels
+        self.NLevels = self._CollArray.shape[0]
 
 
     def _test_lev(self, level):
@@ -481,7 +504,7 @@ class _CollChianti(object):
         else:
             return self._CollArray[lev_i-1, lev_j-1,:]
 
-    def getOmega(self, tem, lev_i= -1, lev_j= -1, NLevelsMax=None):
+    def getOmega(self, tem, lev_i= -1, lev_j= -1):
         """
         Return interpolated value of the collision strength value at the given temperature 
             for the complete array or a specified transition.
@@ -502,20 +525,27 @@ class _CollChianti(object):
         if (lev_i <= lev_j) and (lev_i != -1):
             self.log_.warn("wrong levels given {0} <= {1}".format(lev_i, lev_j), calling=self.calling)
             return None            
+        if self.Chianti2NIST is None:
+            self.Chianti2NIST = get_levs_order(self.atom)
         if (lev_i == -1) and (lev_j == -1):
-            Omega = Chianti_getOmega(self.ion_chianti, tem, Splups=self.Splups, NLevelsMax=NLevelsMax)
-            Chianti2NIST = get_levs_order(self.atom)
-            if Chianti2NIST is not None:
+            Omega = Chianti_getOmega(self.ion_chianti, tem, Splups=self.Splups, NLevels=self.NLevels)
+            if self.Chianti2NIST is not None:
                 Omega_tmp = Omega.copy()
-                for i_chianti in Chianti2NIST:
-                    if Chianti2NIST[i_chianti] != i_chianti:
-                        Omega[i_chianti,:,:] = Omega_tmp[Chianti2NIST[i_chianti],:,:]
-                        Omega[:,i_chianti,:] = Omega_tmp[:,Chianti2NIST[i_chianti],:]
+                for i_chianti in self.Chianti2NIST:
+                    if self.Chianti2NIST[i_chianti] != i_chianti:
+                        Omega[i_chianti,:,:] = Omega_tmp[self.Chianti2NIST[i_chianti],:,:]
+                        Omega[:,i_chianti,:] = Omega_tmp[:,self.Chianti2NIST[i_chianti],:]
         else:
-            Chianti2NIST = get_levs_order(self.atom)
-            if Chianti2NIST is not None:
-                Omega = Chianti_getOmega(self.ion_chianti, tem, lev1=Chianti2NIST[lev_j-1]+1, lev2=Chianti2NIST[lev_i-1]+1, 
-                             Splups=self.Splups, NLevelsMax=NLevelsMax)
+            if self.Chianti2NIST is not None:
+                try:
+                    Omega = Chianti_getOmega(self.ion_chianti, tem, lev1=self.Chianti2NIST[lev_j-1]+1, lev2=self.Chianti2NIST[lev_i-1]+1, 
+                                             Splups=self.Splups, NLevels=self.NLevels)
+                except:
+                    Omega = 0.
+            else:
+                Omega = Chianti_getOmega(self.ion_chianti, tem, lev1=lev_j, lev2=lev_i, 
+                             Splups=self.Splups, NLevels=self.NLevels)
+                
         return np.squeeze(Omega)
 
     def getTemArray(self, keep_unit=True):
@@ -551,5 +581,5 @@ class _CollChianti(object):
     def printSources(self):
         
         for source in self.getSources():
-            print source    
+            print(source)    
         
